# 巨量引擎 MCP 服务器 - 部署指南

## 📦 包构建完成

你的 `oceanengine-mcp-server` 包已经成功构建并准备好发布到 PyPI！

### 构建文件
- `dist/oceanengine_mcp_server-1.0.0-py3-none-any.whl` - Wheel 包
- `dist/oceanengine_mcp_server-1.0.0.tar.gz` - 源码包

## 🚀 发布到 PyPI

### 1. 测试发布（推荐先测试）
```bash
twine upload --repository testpypi dist/*
```

### 2. 正式发布
```bash
twine upload dist/*
```

## 🔧 MCP 客户端配置

### Claude Desktop 配置
在 `~/.claude_desktop_config.json` 中添加：

```json
{
  "mcpServers": {
    "oceanengine": {
      "command": "uvx",
      "args": ["oceanengine-mcp-server"]
    }
  }
}
```

### 其他 MCP 客户端配置
```json
{
  "mcpServers": {
    "oceanengine": {
      "command": "oceanengine-mcp-server"
    }
  }
}
```

## 🛠️ 可用工具

### 1. create_product - 创建商品
创建 DPA 商品
- `advertiser_id`: 广告主ID（必填）
- `access_token`: 访问令牌（必填）
- `platform_id`: 商品平台ID（必填）
- `product_name`: 商品名称（必填）
- `image_url`: 商品图片URL（可选）

### 2. create_asset_and_event - 组合操作（推荐）
创建资产并自动创建事件
- `advertiser_id`: 广告主ID（必填）
- `access_token`: 访问令牌（必填）
- `asset_name`: 资产名称（可选，默认"dsok"）
- `asset_description`: 资产描述（可选，默认为空）
- `event_id`: 事件ID（可选，默认20）

## 📝 使用示例

```python
# 创建商品
create_product(
    advertiser_id="1234567890",
    access_token="your_access_token",
    platform_id="platform_123",
    product_name="我的商品",
    image_url="https://example.com/image.jpg"
)

# 创建资产并自动创建事件
create_asset_and_event(
    advertiser_id="1234567890",
    access_token="your_access_token",
    asset_name="我的资产",
    asset_description="资产描述",
    event_id=20
)
```

## ✅ 特性

- ✅ 无需配置文件，所有参数通过工具调用传入
- ✅ 支持创建 DPA 商品
- ✅ 支持创建资产和事件的组合操作
- ✅ 详细的中文注释和文档
- ✅ 完整的错误处理
- ✅ 符合 MCP 标准

## 🔍 测试

包已通过构建测试，可以安全发布到 PyPI。

## 📞 支持

如有问题，请检查：
1. 广告主ID和访问令牌是否正确
2. 网络连接是否正常
3. API 权限是否充足

---

🎉 **恭喜！你的 MCP 服务器已准备就绪！**