# 巨量引擎 HTTP API 使用指南

## 🌐 HTTP 服务器

除了 MCP 服务器，我们还提供了 HTTP API 服务器，可以通过 HTTP 请求直接调用巨量引擎 API。

## 🚀 启动 HTTP 服务器

```bash
# 启动 HTTP 服务器（默认端口 8000）
oceanengine-http-server
```

服务器启动后，你可以通过以下 URL 访问：
- **基础 URL**: `http://localhost:8000`
- **API 文档**: `http://localhost:8000/docs` (Swagger UI)
- **API 规范**: `http://localhost:8000/redoc` (ReDoc)

## 📡 API 端点

### 1. 根端点
```bash
GET http://localhost:8000/
```

响应：
```json
{
  "name": "OceanEngine API Server",
  "version": "1.0.0",
  "endpoints": [
    "/create-asset",
    "/create-event", 
    "/create-product",
    "/create-asset-and-event"
  ]
}
```

### 2. 创建商品
```bash
POST http://localhost:8000/create-product
```

请求体：
```json
{
  "advertiser_id": "你的广告主ID",
  "access_token": "你的访问令牌",
  "platform_id": "商品库ID",
  "product_name": "商品名称",
  "image_url": "商品图片URL（可选）"
}
```

### 3. 创建资产
```bash
POST http://localhost:8000/create-asset
```

请求体：
```json
{
  "advertiser_id": "你的广告主ID",
  "access_token": "你的访问令牌",
  "name": "资产名称",
  "description": "资产描述（可选）"
}
```

### 4. 创建事件
```bash
POST http://localhost:8000/create-event
```

请求体：
```json
{
  "advertiser_id": "你的广告主ID",
  "access_token": "你的访问令牌",
  "asset_id": "资产ID",
  "event_id": 20
}
```

### 5. 创建资产并自动创建事件（推荐）
```bash
POST http://localhost:8000/create-asset-and-event
```

请求体：
```json
{
  "advertiser_id": "你的广告主ID",
  "access_token": "你的访问令牌",
  "asset_name": "资产名称",
  "asset_description": "资产描述（可选）",
  "event_id": 20
}
```

## 🧪 测试示例

### 使用 curl 测试

```bash
# 测试根端点
curl http://localhost:8000/

# 创建商品
curl -X POST http://localhost:8000/create-product \
  -H "Content-Type: application/json" \
  -d '{
    "advertiser_id": "1234567890",
    "access_token": "your_access_token",
    "platform_id": "platform_123",
    "product_name": "测试商品",
    "image_url": "https://example.com/image.jpg"
  }'

# 创建资产并自动创建事件
curl -X POST http://localhost:8000/create-asset-and-event \
  -H "Content-Type: application/json" \
  -d '{
    "advertiser_id": "1234567890",
    "access_token": "your_access_token",
    "asset_name": "测试资产",
    "asset_description": "这是一个测试资产",
    "event_id": 20
  }'
```

### 使用 Python requests

```python
import requests

# 基础 URL
base_url = "http://localhost:8000"

# 创建商品
response = requests.post(f"{base_url}/create-product", json={
    "advertiser_id": "1234567890",
    "access_token": "your_access_token",
    "platform_id": "platform_123",
    "product_name": "测试商品",
    "image_url": "https://example.com/image.jpg"
})

print(response.json())
```

## 🔧 配置选项

### 自定义端口和主机

```python
# 在 http_server.py 的 main() 函数中修改
uvicorn.run(app, host="0.0.0.0", port=8080)  # 使用端口 8080
```

### 生产环境部署

```bash
# 使用 uvicorn 直接运行
uvicorn oceanengine_mcp_server.http_server:app --host 0.0.0.0 --port 8000

# 或者使用 gunicorn
pip install gunicorn
gunicorn oceanengine_mcp_server.http_server:app -w 4 -k uvicorn.workers.UvicornWorker
```

## 📊 对比：MCP vs HTTP

| 特性 | MCP 服务器 | HTTP 服务器 |
|------|------------|-------------|
| **用途** | 与 AI 助手集成 | 直接 API 调用 |
| **协议** | JSON-RPC over stdio | HTTP REST API |
| **访问方式** | MCP 客户端 | HTTP 请求 |
| **文档** | 内置 prompts | Swagger UI |
| **测试** | MCP 客户端 | curl/Postman |

## 🎯 使用建议

- **MCP 服务器**: 适合与 Claude Desktop 等 AI 助手集成
- **HTTP 服务器**: 适合直接 API 调用、测试和集成到其他系统

两个服务器可以同时运行，互不冲突！