#!/usr/bin/env python3
"""
测试脚本：验证 oceanengine-mcp-server 包的构建和功能
"""

import subprocess
import sys
import json


def test_package_build():
    """测试包构建"""
    print("🔨 测试包构建...")
    try:
        # 构建包
        result = subprocess.run([sys.executable, "-m", "build"], 
                              capture_output=True, text=True)
        if result.returncode == 0:
            print("✅ 包构建成功")
            return True
        else:
            print(f"❌ 包构建失败: {result.stderr}")
            return False
    except Exception as e:
        print(f"❌ 构建过程出错: {e}")
        return False


def test_import():
    """测试导入"""
    print("📦 测试模块导入...")
    try:
        from oceanengine_mcp_server import main
        print("✅ 模块导入成功")
        return True
    except ImportError as e:
        print(f"❌ 模块导入失败: {e}")
        return False


def test_server_functions():
    """测试服务器函数"""
    print("🧪 测试服务器函数...")
    try:
        from oceanengine_mcp_server.server import create_asset_api, create_product_api
        
        # 测试函数是否可调用（使用无效参数，预期会返回错误）
        result1 = create_asset_api("test", "test", "test_asset")
        result2 = create_product_api("test", "test", "test", "test_product")
        
        print("✅ 服务器函数测试通过")
        return True
    except Exception as e:
        print(f"❌ 服务器函数测试失败: {e}")
        return False


def main():
    """主测试函数"""
    print("🚀 开始测试 oceanengine-mcp-server 包\n")
    
    tests = [
        ("导入测试", test_import),
        ("函数测试", test_server_functions),
        ("构建测试", test_package_build),
    ]
    
    passed = 0
    total = len(tests)
    
    for test_name, test_func in tests:
        print(f"\n--- {test_name} ---")
        if test_func():
            passed += 1
        print()
    
    print(f"📊 测试结果: {passed}/{total} 通过")
    
    if passed == total:
        print("🎉 所有测试通过！包已准备好发布到 PyPI")
        print("\n📝 发布步骤:")
        print("1. pip install twine")
        print("2. python -m build")
        print("3. twine upload dist/*")
    else:
        print("⚠️  部分测试失败，请检查问题后重试")
        sys.exit(1)


if __name__ == "__main__":
    main()