#创建项目

# 导入 json 模块，用于处理 JSON 数据
import json
# 导入 requests 模块，用于发送 HTTP 请求
import requests


# 从 zhunbei.json 读取配置
with open('/Users/zhr/Library/Mobile Documents/com~apple~CloudDocs/巨量广告拆解/zhunbei.json', 'r', encoding='utf-8') as f:
    config = json.load(f)

# 定义创建项目的 API 接口地址
url = 'https://api.oceanengine.com/open_api/v3.0/project/create/'
# 定义请求头，包含访问令牌
headers = {
    'Access-Token': config['ACCESS_TOKEN']
}
# 定义请求体，包含创建项目所需的参数
body = {
    # 广告主 ID
    'advertiser_id': config['advertiser_id'],  
    # 项目名称
    'name': 'dsok',            
    # 落地页类型
    'landing_type': 'SHOP',
    # 营销目标
    'marketing_goal': 'VIDEO_AND_IMAGE',
    # 广告类型
    'ad_type': 'ALL',
    # 素材类型
    'asset_type': 'THIRDPARTY',
    # 关联产品信息
    'related_product': {
        # 产品设置类型
        'product_setting': 'SINGLE',
        # 产品平台 ID
        'product_platform_id': config['product_platform_id'],
        # 产品 ID
        'product_id': str(config['product_id'])
    },
    # 优化目标信息
    'optimize_goal': {
        # 素材 ID 列表
        'asset_ids': [config['asset_id']],
        # 外部转化动作类型
        'external_action': 'AD_CONVERT_TYPE_APP_ORDER'
    },
    # 投放范围信息
    'delivery_range': {
        # 库存目录类型
        'inventory_catalog': 'UNIVERSAL_SMART'
    },
    # 投放设置信息
    'delivery_setting': {
        # 投放排期类型
        'schedule_type': 'SCHEDULE_FROM_NOW',
        # 出价类型
        'pricing': 'PRICING_OCPM',
        # 出价模式
        'bid_type': 'CUSTOM',
        # 预算模式
        'budget_mode': 'BUDGET_MODE_DAY',
        # 日预算金额
        'budget': int(config['budget']),
        # CPA 出价金额
        'cpa_bid': int(config['cpa_bid'])
    },
    # 定向设置信息
    'audience': {
        # 性别定向
        'gender': config['gender'],
        # 年龄定向列表
        'age': config['age'],
        # 城市定向列表
        'city': config['city'],
        # 区县定向类型
        'district': 'REGION',
        # 位置定向类型
        'location_type': 'HOME',
        # 地域版本号
        'region_version': '2.3.2',
        # 兴趣行为模式
        'interest_action_mode': 'UNLIMITED'
    },
    # 投放模式
    'delivery_mode': 'PROCEDURAL'
}

# 从 audience.json 读取定向配置
with open('audience.json', 'r', encoding='utf-8') as f:
    audience = json.load(f)
body['audience'] = audience

# 发送 POST 请求，创建项目
response = requests.post(url, headers=headers, json=body)
# 打印响应内容
print(response.text)