#!/usr/bin/env python3
"""
简单的测试脚本，直接调用 MCP 服务器的函数
"""

import json
import sys
import os

# 添加当前目录到 Python 路径
sys.path.insert(0, os.path.dirname(os.path.abspath(__file__)))

from oceanengine_mcp_server.server import create_project_api, create_asset_api, create_event_api, create_product_api


def test_create_project():
    """测试创建项目功能"""
    print("=== 测试创建项目 ===")
    
    # 测试参数
    access_token = "fdb52ca5276eaf832d756a305cd5ee1df93ec981"
    advertiser_id = "1834170090329099"
    name = "测试项目"
    product_platform_id = "6383139949659930"
    product_id = "1752731593405736728"
    asset_id = "1837874387273299"
    budget = 300
    cpa_bid = 3
    audience_template = "moban1"  # 使用模板
    
    print("调用参数:")
    print(f"  access_token: {access_token}")
    print(f"  advertiser_id: {advertiser_id}")
    print(f"  name: {name}")
    print(f"  product_platform_id: {product_platform_id}")
    print(f"  product_id: {product_id}")
    print(f"  asset_id: {asset_id}")
    print(f"  budget: {budget}")
    print(f"  cpa_bid: {cpa_bid}")
    print(f"  audience_template: {audience_template}")
    print()
    
    # 获取模板内容并显示
    from oceanengine_mcp_server.server import get_audience_template
    audience = get_audience_template(audience_template)
    print(f"使用的 audience 模板内容:")
    print(json.dumps(audience, indent=2, ensure_ascii=False))
    print()
    
    # 调用函数
    result = create_project_api(
        access_token=access_token,
        advertiser_id=advertiser_id,
        name=name,
        product_platform_id=product_platform_id,
        product_id=product_id,
        asset_id=asset_id,
        budget=budget,
        cpa_bid=cpa_bid,
        audience=audience
    )
    
    print("调用结果:")
    print(json.dumps(result, indent=2, ensure_ascii=False))
    print()


def test_all_templates():
    """测试所有 audience 模板"""
    print("=== 测试所有 Audience 模板 ===")
    
    from oceanengine_mcp_server.server import AUDIENCE_TEMPLATES
    
    for template_name, template_content in AUDIENCE_TEMPLATES.items():
        print(f"\n模板名称: {template_name}")
        print("模板内容:")
        print(json.dumps(template_content, indent=2, ensure_ascii=False))
        print("-" * 40)


def test_create_asset():
    """测试创建资产功能"""
    print("=== 测试创建资产 ===")
    
    advertiser_id = "1834170090329099"
    access_token = "fdb52ca5276eaf832d756a305cd5ee1df93ec981"
    name = "测试资产"
    description = "这是一个测试资产"
    
    print("调用参数:")
    print(f"  advertiser_id: {advertiser_id}")
    print(f"  access_token: {access_token}")
    print(f"  name: {name}")
    print(f"  description: {description}")
    print()
    
    result = create_asset_api(advertiser_id, access_token, name, description)
    
    print("调用结果:")
    print(json.dumps(result, indent=2, ensure_ascii=False))
    print()


def test_create_product():
    """测试创建商品功能"""
    print("=== 测试创建商品 ===")
    
    advertiser_id = "1834170090329099"
    access_token = "fdb52ca5276eaf832d756a305cd5ee1df93ec981"
    platform_id = "6383139949659930"
    product_name = "测试商品"
    image_url = "https://example.com/test-image.jpg"
    
    print("调用参数:")
    print(f"  advertiser_id: {advertiser_id}")
    print(f"  access_token: {access_token}")
    print(f"  platform_id: {platform_id}")
    print(f"  product_name: {product_name}")
    print(f"  image_url: {image_url}")
    print()
    
    result = create_product_api(advertiser_id, access_token, platform_id, product_name, image_url)
    
    print("调用结果:")
    print(json.dumps(result, indent=2, ensure_ascii=False))
    print()


def main():
    """主函数"""
    print("=== 巨量引擎 API 直接测试工具 ===\n")
    
    while True:
        print("请选择要测试的功能:")
        print("1. 测试创建项目")
        print("2. 测试创建资产")
        print("3. 测试创建商品")
        print("4. 查看所有 Audience 模板")
        print("5. 运行所有测试")
        print("6. 退出")
        
        choice = input("\n请输入选择 (1-6): ").strip()
        
        if choice == "1":
            test_create_project()
        elif choice == "2":
            test_create_asset()
        elif choice == "3":
            test_create_product()
        elif choice == "4":
            test_all_templates()
        elif choice == "5":
            print("=== 运行所有测试 ===\n")
            test_all_templates()
            test_create_asset()
            test_create_product()
            test_create_project()
        elif choice == "6":
            print("退出测试工具")
            break
        else:
            print("无效选择，请重新输入")
        
        print("=" * 60 + "\n")


if __name__ == "__main__":
    main()