# 巨量引擎 MCP 服务器

一个用于巨量引擎 API 操作的 Model Context Protocol (MCP) 服务器，提供资产创建、事件管理和商品创建等功能。

## 功能特性

- **资产管理**: 创建第三方外部资产
- **事件管理**: 为资产创建事件
- **商品管理**: 创建 DPA (动态商品广告) 商品
- **组合操作**: 一键创建资产并自动创建事件

## 安装

```bash
pip install oceanengine-mcp-server
```

## 使用方法

本服务器不需要配置文件，所有参数通过工具调用时直接传入。

### 作为 MCP 服务器

在你的 MCP 客户端配置中添加：

```json
{
    "mcpServers": {
        "oceanengine": {
            "command": "uvx",
            "args": ["oceanengine-mcp-server"]
        }
    }
}
```

### Claude Desktop 配置示例

```json
{
  "mcpServers": {
    "oceanengine": {
      "command": "uvx",
      "args": ["oceanengine-mcp-server"]
    }
  }
}
```

### 可用工具

#### 1. create_product - 创建商品
创建DPA商品
- `advertiser_id`: 广告主ID（必填）
- `access_token`: 访问令牌（必填）
- `platform_id`: 商品库ID（必填）
- `product_name`: 商品名称（必填）
- `image_url`: 商品图片URL（可选）

#### 2. create_asset_and_event - 组合操作（推荐）
创建资产并自动创建事件
- `advertiser_id`: 广告主ID（必填）
- `access_token`: 访问令牌（必填）
- `asset_name`: 资产名称（可选，默认"dsok"）
- `asset_description`: 资产描述（可选，默认为空）
- `event_id`: 事件ID（可选，默认20）

### 使用示例

```python
# 创建商品
create_product(
    advertiser_id="1234567890",
    access_token="your_access_token",
    platform_id="platform_123",
    product_name="我的商品",
    image_url="https://example.com/image.jpg"
)

# 创建资产并自动创建事件
create_asset_and_event(
    advertiser_id="1234567890",
    access_token="your_access_token",
    asset_name="我的资产",
    asset_description="资产描述",
    event_id=20
)
```

## 开发

```bash
# 开发模式安装
pip install -e .

# 运行服务器
oceanengine-mcp-server
```

## 注意事项

- 所有工具都需要提供 `advertiser_id` 和 `access_token` 参数
- 资产创建成功后会返回 `asset_id`，可用于后续创建事件
- 商品创建成功后会返回 `product_id`
- 建议使用 `create_asset_and_event` 进行一键操作
- 所有操作都会返回详细的 API 响应结果

## 许可证

MIT License